"""
Automated Solution Checker
"""

OKGREEN = '\033[92m'
FAIL = '\033[91m'
ENDC = '\033[0m'


def solution_checker(function_code, question_number):
    if question_number == 1:
        test_string = "Hey!! I am Sam with ID number: 007 from Umbrella Corporation office at USA. Call me at 6543291234"
        output = function_code(test_string)
        if output == 'Region: USA, Phone: +1-6543291234':
            result = True
            print(OKGREEN + 'Passed!!' + ENDC)
        else:
            result = False
            print(OKGREEN + 'Oops Failed :(' + ENDC)

    elif question_number == 2:
        test_string = "Kevin Scaria"
        output = function_code(test_string)
        if output == 'Scaria, Kevin':
            result = True
            print(OKGREEN + 'Passed!!' + ENDC)
        else:
            result = False
            print(OKGREEN + 'Oops Failed :(' + ENDC)

    return result



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="auto_checker",
    version="1.0.1",
    author="Kevin Scaria",
    author_email="scariakevin1@gmail.com",
    description="A  light weight package to check the codes of candidates who interview with me.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/kevinscaria/autochecker",
    packages=setuptools.find_packages(),
    classifiers=(
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ),
)
